@@ -1,7 +1,7 @@
 from jinja2 import Environment, PackageLoader
 
-from file_helpers import *
-from str_helpers import auto_str
+from kntgen.file_helpers import *
+from kntgen.str_helpers import auto_str
 
 
 @auto_str
